import scrapy
import re
from scrapy_splash import SplashRequest

"""
Para este sitio se hace uso de 'scrapy-splash' porque el contenido es cargado a traves de javascript

USO:
scrapy crawl noticias -t json --nolog -o noticias.json -a year=2017 -a month=3
"""

TAG_RE = re.compile(r'<[^>]+>')
def remove_tags(text):
	return TAG_RE.sub('', text)


class NoticiasItem(scrapy.Item):
	title = scrapy.Field()
	text = scrapy.Field()
	date = scrapy.Field()
	location = scrapy.Field()
	author = scrapy.Field()
	topic = scrapy.Field()
	url = scrapy.Field()


class QuotesSpider(scrapy.Spider):
	name = "noticias"
	
	def start_requests(self):
		year = getattr(self, 'year', None)
		month = getattr(self, 'month', None)
		# day = getattr(self, 'day', None)
		parse_month = {'1': 'Enero',       '2': 'Febrero',  '3': 'Marzo',      '4': 'Abril',
									 '5': 'Mayo',        '6': 'Junio',    '7': 'Julio',      '8': 'Agosto',
									 '9': 'Septiembre', '10': 'Octubre', '11': 'Noviembre', '12': 'Diciembre'}
		
		self.date = parse_month[month]+' de '+year

		self.baseURL='http://hemeroteca.proceso.com.mx/?page_id=111058&edicion=mexico&page='

		yield scrapy.Request(url=self.baseURL+self.year, callback=self.parse)


	def parse(self, response):
		for post in response.css('div.catpor-box'):
			post_date = post.xpath('./div/span[@class="catpor-published clearfix"]/text()').extract_first()
			post_date = post_date[post_date.find('d')+3:]
			if post_date == self.date:
				link = post.xpath('./div/div/a/@href').extract_first()
				yield scrapy.Request(url=link, callback=self.parse_2)


	def parse_2(self, response):
		for link in response.xpath('//*[@class="post-container clearfix"]/h2/a/@href').extract():
			# yield scrapy.Request(url=link, callback=self.parse_item)
			yield SplashRequest(url=link, callback=self.parse_item, endpoint='render.html', args={ 'wait': 0.5 })


	def parse_item(self, response):
		item = NoticiasItem()
		text = ''
		item['date'] = response.xpath('//div[@id="primary"]/div/div/div/div/span[@class="published"]/text()').extract_first()
		item['title'] = response.xpath('//div[@id="primary"]/div/h1/text()').extract_first()
		item['topic'] = response.xpath('//span[@class="entry-categories"]/text()').extract_first()
		for paragraph in response.xpath('//div[@id="primary"]/div/div/div/div[@class="entry-content"]/div/p').extract():
			text += remove_tags(paragraph) + '\n'
		item['text'] = text
		item['url'] = response.url
		# print item['title']
		yield item

